==> 2.5.zip: piwigo/language/kn_IN/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['Upgrade from version %s to %s'] = '%s ದಿಂದ %s ಕ್ಕೆ ಉನ್ನತೀಕರಿಸಿ';
$lang['total SQL time'] = 'SQL ಸಮಯದ ಒಟ್ಟು ಮೊತ್ತ';
$lang['total upgrade time'] = 'ಉನ್ನತೀಕರಣದ ಸಮಯದ ಒಟ್ಟು ಮೊತ್ತ';
$lang['You do not have access rights to run upgrade'] = 'ಉನ್ನತೀಕರಣವನ್ನು ಕೈಗೊಳ್ಳಲು ನಿಮಗೆ ಹಕ್ಕುಗಳಿಲ್ಲ.';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'ಈ ಪುಟವು ನಿಮ್ಮ ಹಳೆಯ ಪಿವಿಗೋ ಆವೃತ್ತಿಯಿಂದ ಹೊಸ ಆವೃತ್ತಿಯ ಡೇಟಾಬೇಸ್ ಗೆ ಉನ್ನತೀಕರಿಸಲು ಸೂಚಿಸುತ್ತಿದೆ. ಉನ್ನತೀಕರಣದ ಸಹಾಯಕವು ನೀವು ಸಧ್ಯಕ್ಕೆ  <strong>release %s</strong> ಅಥವಾ ಅದರ ಸಮಾನವಾದುದನ್ನು ಉಪಯೋಗಿಸುತ್ತಿದ್ದೀರೆಂದು ಅಂದುಕೊಂಡಿದೆ.';
$lang['User permissions and group permissions have been erased'] = 'ಬಳಕೆದಾರರ ಮತ್ತು ಗುಂಪುಗಳ ಅನುಮತಿಗಳನ್ನು ಅಳಿಸಲಾಗಿದೆ.';
$lang['Upgrade'] = 'ಉನ್ನತೀಕರಿಸಿ';
$lang['Upgrade informations'] = 'ಉನ್ನತೀಕರಣದ ವಿವರಗಳು';
$lang['Statistics'] = 'ಅಂಕಿಅಂಶಗಳು';
$lang['SQL queries'] = 'SQL ಕ್ವೆರಿಗಳು';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'ಏನಾದಾರೂ ತೊಂದರೆ ಉಂಟಾಗಿದ್ದಲ್ಲಿ, ನಿರ್ವಹಣೆ ಚೆಕ್ ಇನ್ ಅನ್ನು ಮಾಡಿ [Administration>Tools>Maintenance] ';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'ಕಿರುಚಿತ್ರದ ಪ್ರತ್ಯಯ ಮತ್ತು ವೆಬ್ ಮಾಸ್ಟರ್ ರ ಮಿಂಚೆ ವಿಳಾಸಗಳನ್ನು ಮಾತ್ರ ಈ ಹಿಂದಿನ ಕಾರ್ಯಸಿದ್ಧತಾ ಪಟ್ಟಿಯಲ್ಲಿ ಉಳಿಸಲಾಗಿದೆ.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'ಕೇವಲ ನಿರ್ವಹಣೆಗಾರರು ಮಾತ್ರ ಉನ್ನತೀಕರಣ ಮಾಡಬಹುದು. ದಯವಿಟ್ಟು ಈ ಕೆಳಗೆ ಸೈನ್ ಇನ್ ಆಗಿರಿ.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '<i>%s</i> ನಲ್ಲಿ, ಮುಂದೆ <b>?></b>, ಸೇರಿಸಿ:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'ಮುನ್ನೆಚ್ಚರಿಕೆಯಾಗಿ, ಈ ಕೆಳಕಂಡ ಥೀಮ್ ಗಳನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ. ಇವುಗಳನ್ನು ಮರುಸಕ್ರಿಯಗೊಳಿಸುವ ಮುನ್ನ ಉನ್ನತೀಕರಿಸಬಹುದಾದ ಥೀಮ್ ಗಳಿಗಾಗಿ ಪರೀಕ್ಷಿಸಿ.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'ಮುನ್ನೆಚ್ಚರಿಕೆಯಾಗಿ, ಈ ಕೆಳಕಂಡ ಪ್ಲಗ್ ಇನ್ ಗಳನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ. ಇವುಗಳನ್ನು ಮರುಸಕ್ರಿಯಗೊಳಿಸುವ ಮುನ್ನ ಉನ್ನತೀಕರಿಸಬಹುದಾದ ಪ್ಲಗ್ ಇನ್ ಗಳಿಗಾಗಿ ಪರೀಕ್ಷಿಸಿ.';
$lang['All sub-albums of private albums become private'] = 'ಎಲ್ಲಾ ಖಾಸಗಿ ಸಂಪುಟಗಳ ಉಪ-ಸಂಪುಟಗಳು ಖಾಸಗಿಯಾಗುತ್ತವೆ';
?>

==> 14.5.0.zip: piwigo/language/kn_IN/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['Upgrade from version %s to %s'] = '%s ದಿಂದ %s ಕ್ಕೆ ಉನ್ನತೀಕರಿಸಿ';
$lang['total SQL time'] = 'SQL ಸಮಯದ ಒಟ್ಟು ಮೊತ್ತ';
$lang['total upgrade time'] = 'ಉನ್ನತೀಕರಣದ ಸಮಯದ ಒಟ್ಟು ಮೊತ್ತ';
$lang['You do not have access rights to run upgrade'] = 'ಉನ್ನತೀಕರಣವನ್ನು ಕೈಗೊಳ್ಳಲು ನಿಮಗೆ ಹಕ್ಕುಗಳಿಲ್ಲ.';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'ಈ ಪುಟವು ನಿಮ್ಮ ಹಳೆಯ ಪಿವಿಗೋ ಆವೃತ್ತಿಯಿಂದ ಹೊಸ ಆವೃತ್ತಿಯ ಡೇಟಾಬೇಸ್ ಗೆ ಉನ್ನತೀಕರಿಸಲು ಸೂಚಿಸುತ್ತಿದೆ. ಉನ್ನತೀಕರಣದ ಸಹಾಯಕವು ನೀವು ಸಧ್ಯಕ್ಕೆ  <strong>release %s</strong> ಅಥವಾ ಅದರ ಸಮಾನವಾದುದನ್ನು ಉಪಯೋಗಿಸುತ್ತಿದ್ದೀರೆಂದು ಅಂದುಕೊಂಡಿದೆ.';
$lang['User permissions and group permissions have been erased'] = 'ಬಳಕೆದಾರರ ಮತ್ತು ಗುಂಪುಗಳ ಅನುಮತಿಗಳನ್ನು ಅಳಿಸಲಾಗಿದೆ.';
$lang['Upgrade'] = 'ಉನ್ನತೀಕರಿಸಿ';
$lang['Upgrade informations'] = 'ಉನ್ನತೀಕರಣದ ವಿವರಗಳು';
$lang['Statistics'] = 'ಅಂಕಿಅಂಶಗಳು';
$lang['SQL queries'] = 'SQL ಕ್ವೆರಿಗಳು';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'ಏನಾದಾರೂ ತೊಂದರೆ ಉಂಟಾಗಿದ್ದಲ್ಲಿ, ನಿರ್ವಹಣೆ ಚೆಕ್ ಇನ್ ಅನ್ನು ಮಾಡಿ [Administration>Tools>Maintenance] ';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'ಕಿರುಚಿತ್ರದ ಪ್ರತ್ಯಯ ಮತ್ತು ವೆಬ್ ಮಾಸ್ಟರ್ ರ ಮಿಂಚೆ ವಿಳಾಸಗಳನ್ನು ಮಾತ್ರ ಈ ಹಿಂದಿನ ಕಾರ್ಯಸಿದ್ಧತಾ ಪಟ್ಟಿಯಲ್ಲಿ ಉಳಿಸಲಾಗಿದೆ.';
$lang['Only administrator can run upgrade: please sign in below.'] = 'ಕೇವಲ ನಿರ್ವಹಣೆಗಾರರು ಮಾತ್ರ ಉನ್ನತೀಕರಣ ಮಾಡಬಹುದು. ದಯವಿಟ್ಟು ಈ ಕೆಳಗೆ ಸೈನ್ ಇನ್ ಆಗಿರಿ.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '<i>%s</i> ನಲ್ಲಿ, ಮುಂದೆ <b>?></b>, ಸೇರಿಸಿ:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'ಮುನ್ನೆಚ್ಚರಿಕೆಯಾಗಿ, ಈ ಕೆಳಕಂಡ ಥೀಮ್ ಗಳನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ. ಇವುಗಳನ್ನು ಮರುಸಕ್ರಿಯಗೊಳಿಸುವ ಮುನ್ನ ಉನ್ನತೀಕರಿಸಬಹುದಾದ ಥೀಮ್ ಗಳಿಗಾಗಿ ಪರೀಕ್ಷಿಸಿ.';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'ಮುನ್ನೆಚ್ಚರಿಕೆಯಾಗಿ, ಈ ಕೆಳಕಂಡ ಪ್ಲಗ್ ಇನ್ ಗಳನ್ನು ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಲಾಗಿದೆ. ಇವುಗಳನ್ನು ಮರುಸಕ್ರಿಯಗೊಳಿಸುವ ಮುನ್ನ ಉನ್ನತೀಕರಿಸಬಹುದಾದ ಪ್ಲಗ್ ಇನ್ ಗಳಿಗಾಗಿ ಪರೀಕ್ಷಿಸಿ.';
$lang['All sub-albums of private albums become private'] = 'ಎಲ್ಲಾ ಖಾಸಗಿ ಸಂಪುಟಗಳ ಉಪ-ಸಂಪುಟಗಳು ಖಾಸಗಿಯಾಗುತ್ತವೆ';
$lang['Discover what\'s new in Piwigo %s'] = 'Piwigo %s ರಲ್ಲಿ ಹೊಸತೇನಿದೆ ಅನ್ವೇಷಿಸಿ';
